'use strict';
const lighthouse = require('lighthouse');
const chromeLauncher = require('chrome-launcher');
const fs = require("fs");


const launchChromeAndRunLighthouse = (url, flags, config = null) => {
    return chromeLauncher.launch()
        .then(chrome => {
            flags.port = chrome.port;
            return lighthouse(url, flags, config)
                .then(results =>
                    chrome.kill()
                        .then(() => results)
                );
        });
}

const flags = {
    output: 'html'
};


const getJsonReport = (url) => {
    console.log(url);
    launchChromeAndRunLighthouse(url, flags)
        .then(results => {
            fs.writeFile('./result.html', JSON.stringify(results), function (err) {
                if (err) {
                    return console.log(err);
                }
                console.log('The file was saved!');
            });
        });
}

const getHtmlReport = async (url) => {
    const chrome = await chromeLauncher.launch({ chromeFlags: ['--headless'] });
    const options = { logLevel: 'info', output: 'html', port: chrome.port };
    const runnerResult = await lighthouse(url, options);

    // `.report` is the HTML report as a string
    const reportHtml = runnerResult.report;
    fs.writeFileSync('report.html', reportHtml);
    // fs.writeFileSync('report.json', reportHtml)

    // `.lhr` is the Lighthouse Result as a JS object
    console.log('Report is done for', runnerResult.lhr.finalDisplayedUrl);
    console.log('Performance score was', runnerResult.lhr.categories.performance.score * 100);

    await chrome.kill();
}


module.exports = {
    getJsonReport: getJsonReport,
    getHtmlReport: getHtmlReport
};